==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DataConnectData.java <==
package com.example.model;

/**
 * Model for DataConnectData
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "DataConnectData", description = "Model for DataConnectData")
@javax.xml.bind.annotation.XmlRootElement(name = "DataConnectData")
public class DataConnectData implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.FieldDetails fieldDetails = null;
	private java.lang.String rapidID = null;
	private com.example.model.VerifyDocumentResult verifyDocumentResult = null;
	
	/**
	 * Model for FieldDetails
	 */
	public DataConnectData fieldDetails(com.example.model.FieldDetails fieldDetails) {
		setFieldDetails(fieldDetails);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for FieldDetails")
	@com.fasterxml.jackson.annotation.JsonProperty("fieldDetails")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.FieldDetails getFieldDetails() {
		return this.fieldDetails;
	}
	public void setFieldDetails(com.example.model.FieldDetails fieldDetails) {
		this.fieldDetails = fieldDetails;
	}
	
	/**
	 */
	public DataConnectData rapidID(java.lang.String rapidID) {
		setRapidID(rapidID);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("rapidID")
	public java.lang.String getRapidID() {
		return this.rapidID;
	}
	public void setRapidID(java.lang.String rapidID) {
		this.rapidID = rapidID;
	}
	
	/**
	 * Model for VerifyDocumentResult
	 */
	public DataConnectData verifyDocumentResult(com.example.model.VerifyDocumentResult verifyDocumentResult) {
		setVerifyDocumentResult(verifyDocumentResult);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for VerifyDocumentResult")
	@com.fasterxml.jackson.annotation.JsonProperty("VerifyDocumentResult")
	@javax.validation.Valid
	public com.example.model.VerifyDocumentResult getVerifyDocumentResult() {
		return this.verifyDocumentResult;
	}
	public void setVerifyDocumentResult(com.example.model.VerifyDocumentResult verifyDocumentResult) {
		this.verifyDocumentResult = verifyDocumentResult;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DataConnectData dataConnectData = (DataConnectData) o;
		return java.util.Objects.equals(this.fieldDetails, dataConnectData.fieldDetails)
				&& java.util.Objects.equals(this.rapidID, dataConnectData.rapidID)
				&& java.util.Objects.equals(this.verifyDocumentResult, dataConnectData.verifyDocumentResult);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.fieldDetails, this.rapidID, this.verifyDocumentResult);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DataConnectData {\n");
		
		sb.append("    fieldDetails: ").append(toIndentedString(this.fieldDetails)).append("\n");
		sb.append("    rapidID: ").append(toIndentedString(this.rapidID)).append("\n");
		sb.append("    verifyDocumentResult: ").append(toIndentedString(this.verifyDocumentResult)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DataConnectData.java <==
package com.example.model;

/**
 * Model for DataConnectData
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "DataConnectData", description = "Model for DataConnectData")
@javax.xml.bind.annotation.XmlRootElement(name = "DataConnectData")
public class DataConnectData implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.FieldDetails fieldDetails = null;
	private java.lang.String rapidID = null;
	private com.example.model.VerifyDocumentResult verifyDocumentResult = null;
	
	/**
	 * Model for FieldDetails
	 */
	public DataConnectData fieldDetails(com.example.model.FieldDetails fieldDetails) {
		setFieldDetails(fieldDetails);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "fieldDetails", description = "Model for FieldDetails")
	@com.fasterxml.jackson.annotation.JsonProperty("fieldDetails")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.FieldDetails getFieldDetails() {
		return this.fieldDetails;
	}
	public void setFieldDetails(com.example.model.FieldDetails fieldDetails) {
		this.fieldDetails = fieldDetails;
	}
	
	/**
	 */
	public DataConnectData rapidID(java.lang.String rapidID) {
		setRapidID(rapidID);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "rapidID")
	@com.fasterxml.jackson.annotation.JsonProperty("rapidID")
	public java.lang.String getRapidID() {
		return this.rapidID;
	}
	public void setRapidID(java.lang.String rapidID) {
		this.rapidID = rapidID;
	}
	
	/**
	 * Model for VerifyDocumentResult
	 */
	public DataConnectData verifyDocumentResult(com.example.model.VerifyDocumentResult verifyDocumentResult) {
		setVerifyDocumentResult(verifyDocumentResult);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "VerifyDocumentResult", description = "Model for VerifyDocumentResult")
	@com.fasterxml.jackson.annotation.JsonProperty("VerifyDocumentResult")
	@javax.validation.Valid
	public com.example.model.VerifyDocumentResult getVerifyDocumentResult() {
		return this.verifyDocumentResult;
	}
	public void setVerifyDocumentResult(com.example.model.VerifyDocumentResult verifyDocumentResult) {
		this.verifyDocumentResult = verifyDocumentResult;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DataConnectData dataConnectData = (DataConnectData) o;
		return java.util.Objects.equals(this.fieldDetails, dataConnectData.fieldDetails)
				&& java.util.Objects.equals(this.rapidID, dataConnectData.rapidID)
				&& java.util.Objects.equals(this.verifyDocumentResult, dataConnectData.verifyDocumentResult);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.fieldDetails, this.rapidID, this.verifyDocumentResult);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DataConnectData {\n");
		
		sb.append("    fieldDetails: ").append(toIndentedString(this.fieldDetails)).append("\n");
		sb.append("    rapidID: ").append(toIndentedString(this.rapidID)).append("\n");
		sb.append("    verifyDocumentResult: ").append(toIndentedString(this.verifyDocumentResult)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
